const AJV = require('ajv')
const ajv = new AJV()

const schema = {
  "type": "object",
  "properties": {
    "tex":    { "type": "string" },
    "to":     { "type": "string" },
    "math":   { "type": "boolean", "enum": [ true ] },
    "space":  { "type": "boolean", "enum": [ true ] },
    "from":   { "oneOf": [ { "type": "string" }, { "type": "array", "items": { "type": "string" }, "minItems": 1 } ] }
  },
  "allOf": [
    { "oneOf": [
        { "required": [ "tex" ], "not": { "required": [ "to" ] } },
        { "required": [ "to" ], "not": { "required": [ "tex", "from" ] } },
    ]}
  ],
  "additionalProperties": false
}

const validate = ajv.compile(schema)

validate({"tex":"\\textexclamdown"})
console.log(`should succeed:`, validate.errors || true)

validate({"tex":"\\textexclamdown", "from": "x" })
console.log(`should succeed:`, validate.errors || true)

validate({"tex":"\\textexclamdown", "notfrom": "x" })
console.log(`should fail for notfrom:`, validate.errors || true)

validate({"to":"\\textexclamdown", "from": "x" })
console.log(`should fail:`, validate.errors || true)

